@@ -351,6 +351,7 @@ class _TestRPCRequest(BaseModel):
     we do not want to depend on openmodule, this is a minimal version of the zmq message for the rpc function
     """
     timestamp: float = Field(default_factory=time.time)
+    resource: str = settings.RESOURCE
     name: str
     type: str
     rpc_id: UUID
@@ -427,7 +428,7 @@ class ZMQTestMixin(TestCase):
         Schema.to_file()
         settings.reset()
 
-    def rpc(self, channel: str, type: str, request, timeout=3, receive_response=True) -> Optional[dict]:
+    def rpc(self, channel: str, type: str, request, timeout=3, receive_response=True, resource=None) -> Optional[dict]:
         response_topic = f"rpc-rep-{channel}".encode("ascii")
         if response_topic not in self.zmq_client.subscribed_topics:
             raise DeveloperError(
@@ -436,7 +437,8 @@ class ZMQTestMixin(TestCase):
             )
 
         rpc_id = str(uuid4())
-        rpc_request = _TestRPCRequest(name="testclient", type=type, rpc_id=rpc_id, request=request)
+        rpc_request = _TestRPCRequest(name="testclient", type=type, rpc_id=rpc_id,
+                                      resource=resource or settings.RESOURCE, request=request)
         self.zmq_client.send(f"rpc-req-{channel}".encode("ascii"), rpc_request)
         if receive_response:
             _, response = self.zmq_client.wait_for_message(
